@@ -1,22 +1,21 @@
 // -*- C++ -*-
-/* Copyright (C) 2000, 2001, 2003, 2004 Free Software Foundation, Inc.
+/* Copyright (C) 2000, 2001, 2003, 2004, 2005, 2009 Free Software Foundation, Inc.
      Written by Gaius Mulley (gaius@glam.ac.uk).
 
 This file is part of groff.
 
 groff is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
-Software Foundation; either version 2, or (at your option) any later
-version.
+Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 groff is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
 FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
-You should have received a copy of the GNU General Public License along
-with groff; see the file COPYING.  If not, write to the Free Software
-Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+You should have received a copy of the GNU General Public License
+along with this program. If not, see <http://www.gnu.org/licenses/>. */
 
 #include "lib.h"
 
@@ -83,14 +82,12 @@ pushBackBuffer::pushBackBuffer (char *filename)
 
 pushBackBuffer::~pushBackBuffer ()
 {
-  int old;
-
   if (charStack != 0) {
     free(charStack);
   }
   close(0);
   /* restore stdin in file descriptor 0 */
-  old = dup(stdIn);
+  dup(stdIn);
   close(stdIn);
 }
 
@@ -162,10 +159,8 @@ static int isWhite (char ch)
 
 void pushBackBuffer::skipToNewline (void)
 {
-  char ch;
-
   while ((putPB(getPB()) != '\n') && (! eofFound)) {
-    ch = getPB();
+    getPB();
   }
 }
 
