@@ -1,6 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001, 2002, 2003, 2004, 2005,
-                 2006, 2009
+/* Copyright (C) 1989-1992, 2000-2006, 2009, 2011
    Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
@@ -2213,14 +2212,15 @@ node *environment::make_tag(const char *nm, int i)
      */
     if (curdiv == topdiv && topdiv->before_first_page)
       topdiv->begin_page();
-    macro *m = new macro;
-    m->append_str("devtag:");
+
+    macro m;
+    m.append_str("devtag:");
     for (const char *p = nm; *p; p++)
       if (!invalid_input_char((unsigned char)*p))
-	m->append(*p);
-    m->append(' ');
-    m->append_int(i);
-    return new special_node(*m);
+	m.append(*p);
+    m.append(' ');
+    m.append_int(i);
+    return new special_node(m);
   }
   return 0;
 }
@@ -3210,7 +3210,7 @@ const char *sptoa(int sp)
   double factor = 10.0;
   double val = s;
   int decimal_point = 0;
-  do  {
+  do {
     double v = ceil(s*factor);
     if (v > INT_MAX)
       break;
@@ -3313,8 +3313,8 @@ void environment::print_env()
 	       ? "on"
 	       : margin_character_flags == MARGIN_CHARACTER_NEXT
 		   ? "next"
-		   : margin_character_flags == MARGIN_CHARACTER_ON
-					       | MARGIN_CHARACTER_NEXT
+		   : margin_character_flags == (MARGIN_CHARACTER_ON
+						| MARGIN_CHARACTER_NEXT)
 		       ? "on, next"
 		       : "none");
     errprint("  margin character distance: %1u\n",
